<?php

use NCSU\Auth\Adapter\ShibAuthAdapter;
use NCSU\Auth\Adapter\MockAuthAdapter;
use NCSU\Auth\AuthService;
use NCSU\Auth\Exception\RuntimeException;
use NCSU\Auth\Http\Request;

if (! function_exists('ncstate_auth')) {
    /**
     * Authenticates a user using the suggested default authentication
     * adapter.
     *
     * @param string $identity A mock identity to be used for testing
     * @return string the authenticated user's username
     */
    function ncstate_auth($identity = null)
    {
        if ($identity != null) {
            $authAdapter = new MockAuthAdapter($identity);
        } else {
            $authAdapter = new ShibAuthAdapter(Request::createFromGlobals());
        }

        $service = new AuthService($authAdapter);
        $result = $service->authenticate();

        if (! $result->isValid()) {
            throw new RuntimeException('Failed to authenticate via Shibboleth.');
        }

        return $result->getIdentity();
    }
}